struct VirtualPath(String);Expand description
/-separated virtual path.
This is used to describe files that do not reside on the file system.
Tuple Fields
0: StringImplementations
Sourceimpl VirtualPath
impl VirtualPath
Sourcefn starts_with(&self, other: &VirtualPath) -> bool
fn starts_with(&self, other: &VirtualPath) -> bool
Returns true if other is a prefix of self (as strings).
fn strip_prefix(&self, base: &VirtualPath) -> Option<&RelPath>
Sourcefn pop(&mut self) -> bool
fn pop(&mut self) -> bool
Remove the last component of self.
This will find the last '/' in self, and remove everything after it,
including the '/'.
If self contains no '/', returns false; else returns true.
Example
ⓘ
let mut path = VirtualPath("/foo/bar".to_string());
path.pop();
assert_eq!(path.0, "/foo");
path.pop();
assert_eq!(path.0, "");Sourcefn join(&self, path: &str) -> Option<VirtualPath>
fn join(&self, path: &str) -> Option<VirtualPath>
Sourcefn name_and_extension(&self) -> Option<(&str, Option<&str>)>
fn name_and_extension(&self) -> Option<(&str, Option<&str>)>
Returns self’s base name and file extension.
Returns
Noneifselfends with"//".Some((name, None))ifself’s base contains no., or only one.at the start.Some((name, Some(extension))else.
Note
The extension will not contains .. This means "/foo/bar.baz.rs" will
return Some(("bar.baz", Some("rs")).